// src/identity-roles-v1-user-users.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/identity-roles-v1-user-users.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressRolesManagementApiRolesManagementServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      },
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/app/accept",
        destPath: "/app/accept"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/roles-management-web",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/v2/contributors",
        destPath: "/v2/contributors"
      },
      {
        srcPath: "/contributor/change/role",
        destPath: "/contributor/change/role"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/roles-management",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management/roles",
        destPath: "/roles"
      },
      {
        srcPath: "/roles-management/team",
        destPath: "/team"
      },
      {
        srcPath: "/roles-management/v3/team",
        destPath: "/v3/team"
      },
      {
        srcPath: "/roles-management/v2/team",
        destPath: "/v2/team"
      },
      {
        srcPath: "/roles-management/contributor/change",
        destPath: "/contributor/change"
      },
      {
        srcPath: "/roles-management/v2/contributors",
        destPath: "/v2/contributors"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_users";
function removeMember(payload) {
  function __removeMember({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "POST",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.RemoveMember",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/team/remove",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __removeMember;
}
function searchTeam(payload) {
  function __searchTeam({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "POST",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.SearchTeam",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v3/team/search",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "teamMembers.user.joinedTeamAt" },
            { path: "teamMembers.invite.dateCreated" },
            { path: "teamMembers.invite.dateUpdated" },
            { path: "teamMembers.invite.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __searchTeam;
}
function getRolesInfo(payload) {
  function __getRolesInfo({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.GetRolesInfo",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/roles",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getRolesInfo;
}
function changeRoleV2(payload) {
  function __changeRoleV2({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "PATCH",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.ChangeRoleV2",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v2/team/roles",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeRoleV2;
}
function updateTeamMemberAssignments(payload) {
  function __updateTeamMemberAssignments({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "PATCH",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.UpdateTeamMemberAssignments",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v2/team/assignments",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __updateTeamMemberAssignments;
}

// src/identity-roles-v1-user-users.universal.ts
var ResourceType = /* @__PURE__ */ ((ResourceType2) => {
  ResourceType2["UNKNOWN_RESOURCE_TYPE"] = "UNKNOWN_RESOURCE_TYPE";
  ResourceType2["SITE"] = "SITE";
  return ResourceType2;
})(ResourceType || {});
var ConditionAttributeType = /* @__PURE__ */ ((ConditionAttributeType2) => {
  ConditionAttributeType2["UNKNOWN_CONDITION_TYPE"] = "UNKNOWN_CONDITION_TYPE";
  ConditionAttributeType2["FOLDER"] = "FOLDER";
  return ConditionAttributeType2;
})(ConditionAttributeType || {});
var SubjectType = /* @__PURE__ */ ((SubjectType2) => {
  SubjectType2["UNKNOWN"] = "UNKNOWN";
  SubjectType2["ACCOUNT"] = "ACCOUNT";
  SubjectType2["USER"] = "USER";
  SubjectType2["USER_GROUP"] = "USER_GROUP";
  SubjectType2["MEMBER_GROUP"] = "MEMBER_GROUP";
  SubjectType2["VISITOR_GROUP"] = "VISITOR_GROUP";
  SubjectType2["EXTERNAL_APP"] = "EXTERNAL_APP";
  SubjectType2["ACCOUNT_GROUP"] = "ACCOUNT_GROUP";
  SubjectType2["WIX_APP"] = "WIX_APP";
  return SubjectType2;
})(SubjectType || {});
var SubjectContextType = /* @__PURE__ */ ((SubjectContextType2) => {
  SubjectContextType2["UNKNOWN_CTX"] = "UNKNOWN_CTX";
  SubjectContextType2["ORG_CTX"] = "ORG_CTX";
  SubjectContextType2["ACCOUNT_CTX"] = "ACCOUNT_CTX";
  return SubjectContextType2;
})(SubjectContextType || {});
var InviteStatus = /* @__PURE__ */ ((InviteStatus2) => {
  InviteStatus2["Pending"] = "Pending";
  InviteStatus2["Used"] = "Used";
  InviteStatus2["Deleted"] = "Deleted";
  InviteStatus2["Declined"] = "Declined";
  InviteStatus2["Expired"] = "Expired";
  return InviteStatus2;
})(InviteStatus || {});
var SimpleConditionOperator = /* @__PURE__ */ ((SimpleConditionOperator2) => {
  SimpleConditionOperator2["UNKNOWN_SIMPLE_OP"] = "UNKNOWN_SIMPLE_OP";
  SimpleConditionOperator2["EQUAL"] = "EQUAL";
  return SimpleConditionOperator2;
})(SimpleConditionOperator || {});
var JoinedConditionOperator = /* @__PURE__ */ ((JoinedConditionOperator2) => {
  JoinedConditionOperator2["UNKNOWN_JOIN_OP"] = "UNKNOWN_JOIN_OP";
  JoinedConditionOperator2["OR"] = "OR";
  JoinedConditionOperator2["AND"] = "AND";
  return JoinedConditionOperator2;
})(JoinedConditionOperator || {});
var ScopeLevel = /* @__PURE__ */ ((ScopeLevel2) => {
  ScopeLevel2["None"] = "None";
  ScopeLevel2["SITE"] = "SITE";
  ScopeLevel2["ACCOUNT"] = "ACCOUNT";
  return ScopeLevel2;
})(ScopeLevel || {});
var Visibility = /* @__PURE__ */ ((Visibility2) => {
  Visibility2["VISIBLE"] = "VISIBLE";
  Visibility2["BLOCKED_BY_CAPABILITY"] = "BLOCKED_BY_CAPABILITY";
  return Visibility2;
})(Visibility || {});
var PeopleType = /* @__PURE__ */ ((PeopleType2) => {
  PeopleType2["UNDEF_PEOPLE_TYPE"] = "UNDEF_PEOPLE_TYPE";
  PeopleType2["CONTRIBUTOR"] = "CONTRIBUTOR";
  PeopleType2["TEAM_MEMBER"] = "TEAM_MEMBER";
  return PeopleType2;
})(PeopleType || {});
var RoleLevel = /* @__PURE__ */ ((RoleLevel2) => {
  RoleLevel2["ALL"] = "ALL";
  RoleLevel2["SITE_LEVEL"] = "SITE_LEVEL";
  RoleLevel2["ACCOUNT_LEVEL"] = "ACCOUNT_LEVEL";
  return RoleLevel2;
})(RoleLevel || {});
var OrderField = /* @__PURE__ */ ((OrderField2) => {
  OrderField2["Undefined"] = "Undefined";
  OrderField2["Name"] = "Name";
  OrderField2["JoinedAt"] = "JoinedAt";
  return OrderField2;
})(OrderField || {});
var Direction = /* @__PURE__ */ ((Direction2) => {
  Direction2["UninitializedDirection"] = "UninitializedDirection";
  Direction2["ASC"] = "ASC";
  Direction2["DESC"] = "DESC";
  return Direction2;
})(Direction || {});
var FacetType = /* @__PURE__ */ ((FacetType2) => {
  FacetType2["Undefined"] = "Undefined";
  FacetType2["Roles"] = "Roles";
  FacetType2["InviteStatus"] = "InviteStatus";
  FacetType2["Users"] = "Users";
  return FacetType2;
})(FacetType || {});
var RoleLevelRestriction = /* @__PURE__ */ ((RoleLevelRestriction2) => {
  RoleLevelRestriction2["NoRestriction"] = "NoRestriction";
  RoleLevelRestriction2["Site"] = "Site";
  RoleLevelRestriction2["Account"] = "Account";
  return RoleLevelRestriction2;
})(RoleLevelRestriction || {});
var EditorType = /* @__PURE__ */ ((EditorType2) => {
  EditorType2["UNINITIALIZED"] = "UNINITIALIZED";
  EditorType2["EDITORX"] = "EDITORX";
  EditorType2["BLOCKS"] = "BLOCKS";
  EditorType2["STUDIO"] = "STUDIO";
  return EditorType2;
})(EditorType || {});
var RoleVisibility = /* @__PURE__ */ ((RoleVisibility2) => {
  RoleVisibility2["Visible"] = "Visible";
  RoleVisibility2["Disabled_Dependency"] = "Disabled_Dependency";
  RoleVisibility2["Disabled_Capability"] = "Disabled_Capability";
  return RoleVisibility2;
})(RoleVisibility || {});
var PolicyType = /* @__PURE__ */ ((PolicyType2) => {
  PolicyType2["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
  PolicyType2["PREDEFINED"] = "PREDEFINED";
  PolicyType2["CUSTOM"] = "CUSTOM";
  PolicyType2["INLINE_CUSTOM"] = "INLINE_CUSTOM";
  return PolicyType2;
})(PolicyType || {});
var Effect = /* @__PURE__ */ ((Effect2) => {
  Effect2["UNKNOWN_EFFECT"] = "UNKNOWN_EFFECT";
  Effect2["ALLOW"] = "ALLOW";
  Effect2["DENY"] = "DENY";
  return Effect2;
})(Effect || {});
var Host = /* @__PURE__ */ ((Host2) => {
  Host2["INVALID_HOST"] = "INVALID_HOST";
  Host2["BUSINESS_MANAGER"] = "BUSINESS_MANAGER";
  Host2["CHANNELS"] = "CHANNELS";
  Host2["ENTERPRISE"] = "ENTERPRISE";
  Host2["STUDIO_HOST"] = "STUDIO_HOST";
  Host2["DEV_CENTER"] = "DEV_CENTER";
  return Host2;
})(Host || {});
async function removeMember2(userId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ userId });
  const reqOpts = removeMember(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { userId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["userId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function searchTeam2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    query: options?.query,
    orderBy: options?.orderBy,
    filter: options?.filter,
    facets: options?.facets,
    paging: options?.paging
  });
  const reqOpts = searchTeam(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          query: "$[0].query",
          orderBy: "$[0].orderBy",
          filter: "$[0].filter",
          facets: "$[0].facets",
          paging: "$[0].paging"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getRolesInfo2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    locale: options?.locale,
    filter: options?.filter
  });
  const reqOpts = getRolesInfo(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          locale: "$[0].locale",
          filter: "$[0].filter"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function changeRoleV22(userId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    userId,
    roles: options?.roles,
    assignmentIdsToReplace: options?.assignmentIdsToReplace
  });
  const reqOpts = changeRoleV2(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          userId: "$[0]",
          roles: "$[1].roles",
          assignmentIdsToReplace: "$[1].assignmentIdsToReplace"
        },
        singleArgumentUnchanged: false
      },
      ["userId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateTeamMemberAssignments2(userId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    userId,
    newAssignments: options?.newAssignments,
    assignmentIdsToRemove: options?.assignmentIdsToRemove
  });
  const reqOpts = updateTeamMemberAssignments(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          userId: "$[0]",
          newAssignments: "$[1].newAssignments",
          assignmentIdsToRemove: "$[1].assignmentIdsToRemove"
        },
        singleArgumentUnchanged: false
      },
      ["userId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/identity-roles-v1-user-users.public.ts
function removeMember3(httpClient) {
  return (userId) => removeMember2(
    userId,
    // @ts-ignore
    { httpClient }
  );
}
function searchTeam3(httpClient) {
  return (options) => searchTeam2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function getRolesInfo3(httpClient) {
  return (options) => getRolesInfo2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function changeRoleV23(httpClient) {
  return (userId, options) => changeRoleV22(
    userId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function updateTeamMemberAssignments3(httpClient) {
  return (userId, options) => updateTeamMemberAssignments2(
    userId,
    options,
    // @ts-ignore
    { httpClient }
  );
}

// src/identity-roles-v1-user-users.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var removeMember4 = /* @__PURE__ */ createRESTModule(removeMember3);
var searchTeam4 = /* @__PURE__ */ createRESTModule(searchTeam3);
var getRolesInfo4 = /* @__PURE__ */ createRESTModule(getRolesInfo3);
var changeRoleV24 = /* @__PURE__ */ createRESTModule(changeRoleV23);
var updateTeamMemberAssignments4 = /* @__PURE__ */ createRESTModule(updateTeamMemberAssignments3);
export {
  ConditionAttributeType,
  Direction,
  EditorType,
  Effect,
  FacetType,
  Host,
  InviteStatus,
  JoinedConditionOperator,
  OrderField,
  PeopleType,
  PolicyType,
  ResourceType,
  RoleLevel,
  RoleLevelRestriction,
  RoleVisibility,
  ScopeLevel,
  SimpleConditionOperator,
  SubjectContextType,
  SubjectType,
  Visibility,
  changeRoleV24 as changeRoleV2,
  getRolesInfo4 as getRolesInfo,
  removeMember4 as removeMember,
  searchTeam4 as searchTeam,
  updateTeamMemberAssignments4 as updateTeamMemberAssignments
};
//# sourceMappingURL=index.mjs.map