import { aq as RemoveMemberRequest$1, ar as RemoveMemberResponse$1, aR as SearchTeamRequest$1, a as SearchTeamResponse$1, b5 as GetRolesInfoRequest$1, b as GetRolesInfoResponse$1, bc as ChangeRoleV2Request$1, c as ChangeRoleV2Response$1, bd as UpdateTeamMemberAssignmentsRequest$1, d as UpdateTeamMemberAssignmentsResponse$1 } from './identity-roles-v1-user-users.universal-Drs4mXpg.js';

interface Name {
    /** User's first name. */
    firstName?: string;
    /** User's last name. */
    lastName?: string;
}
interface Restriction extends RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: ApiResource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
/** @oneof */
interface RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: ApiResource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
interface ApiResource {
    /** Resource type. */
    resourceType?: ResourceTypeWithLiterals;
    /** Resource ID. */
    id?: string;
    value?: string | null;
}
declare enum ResourceType {
    UNKNOWN_RESOURCE_TYPE = "UNKNOWN_RESOURCE_TYPE",
    SITE = "SITE"
}
/** @enumType */
type ResourceTypeWithLiterals = ResourceType | 'UNKNOWN_RESOURCE_TYPE' | 'SITE';
interface Conditions {
    /** List of conditions. */
    conditions?: ApiCondition[];
}
interface ApiCondition {
    /** Condition type. */
    conditionType?: ConditionAttributeTypeWithLiterals;
    /** Condition ID. */
    id?: string;
    /** Expected value of the condition. When `conditionType` = "FOLDER", this is the folder path. */
    value?: string | null;
}
declare enum ConditionAttributeType {
    UNKNOWN_CONDITION_TYPE = "UNKNOWN_CONDITION_TYPE",
    FOLDER = "FOLDER"
}
/** @enumType */
type ConditionAttributeTypeWithLiterals = ConditionAttributeType | 'UNKNOWN_CONDITION_TYPE' | 'FOLDER';
interface SiteRestriction {
    /** Site ID. */
    id?: string;
    /** Site name. */
    value?: string | null;
}
interface LocationsRestriction {
    /**
     * Location IDs.
     * @format GUID
     * @maxSize 20
     */
    ids?: string[];
}
declare enum SubjectType {
    UNKNOWN = "UNKNOWN",
    ACCOUNT = "ACCOUNT",
    USER = "USER",
    USER_GROUP = "USER_GROUP",
    MEMBER_GROUP = "MEMBER_GROUP",
    VISITOR_GROUP = "VISITOR_GROUP",
    EXTERNAL_APP = "EXTERNAL_APP",
    ACCOUNT_GROUP = "ACCOUNT_GROUP",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type SubjectTypeWithLiterals = SubjectType | 'UNKNOWN' | 'ACCOUNT' | 'USER' | 'USER_GROUP' | 'MEMBER_GROUP' | 'VISITOR_GROUP' | 'EXTERNAL_APP' | 'ACCOUNT_GROUP' | 'WIX_APP';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
/** Invite status stating whether the invite was accepted, waiting to be accepted, deleted etc.. */
declare enum InviteStatus {
    Pending = "Pending",
    Used = "Used",
    Deleted = "Deleted",
    Declined = "Declined",
    Expired = "Expired"
}
/** @enumType */
type InviteStatusWithLiterals = InviteStatus | 'Pending' | 'Used' | 'Deleted' | 'Declined' | 'Expired';
interface RemoveMemberRequest {
    /** User ID of the team member to remove. */
    userId: string;
}
interface RemoveMemberResponse {
}
declare enum RoleLevel {
    ALL = "ALL",
    SITE_LEVEL = "SITE_LEVEL",
    ACCOUNT_LEVEL = "ACCOUNT_LEVEL"
}
/** @enumType */
type RoleLevelWithLiterals = RoleLevel | 'ALL' | 'SITE_LEVEL' | 'ACCOUNT_LEVEL';
interface SearchTeamRequest {
    /** Free text to search for within team member name and email address fields. */
    query?: string | null;
    /** Sort data. */
    orderBy?: Ordering[];
    /**
     * Filter object. Supported values: `inviteType` and `roleId`. For example, `{'inviteType': {'$eq': 'Expired'}}`.
     * See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more information.
     */
    filter?: Record<string, any> | null;
    /**
     * A list of facets to return in the response. Facets count the items within logical groupings.
     * See [Filters and Facets: An Explainer](https://medium.com/@westontt/filters-and-facets-an-explainer-3b73a9538eca) for more information.
     */
    facets?: FacetTypeWithLiterals[];
    /** Pagination. */
    paging?: Paging;
}
interface Ordering {
    /** Field to sort by. */
    fieldName?: OrderFieldWithLiterals;
    /** Sort order. */
    direction?: DirectionWithLiterals;
}
declare enum OrderField {
    /** For internal use. */
    Undefined = "Undefined",
    /** Team member name. */
    Name = "Name",
    /** Date team member joined the account. */
    JoinedAt = "JoinedAt"
}
/** @enumType */
type OrderFieldWithLiterals = OrderField | 'Undefined' | 'Name' | 'JoinedAt';
declare enum Direction {
    /** For internal use. */
    UninitializedDirection = "UninitializedDirection",
    /** Ascending. */
    ASC = "ASC",
    /** Descending. */
    DESC = "DESC"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'UninitializedDirection' | 'ASC' | 'DESC';
declare enum FacetType {
    Undefined = "Undefined",
    /** How many team members with each role */
    Roles = "Roles",
    /** How many team members by invite status */
    InviteStatus = "InviteStatus",
    /** How many team members in total in the account */
    Users = "Users"
}
/** @enumType */
type FacetTypeWithLiterals = FacetType | 'Undefined' | 'Roles' | 'InviteStatus' | 'Users';
interface SearchTeamResponse {
    /** List of facets, as requested. */
    facets?: Facet[];
    /** Existing team members and invites sent to join the account. */
    teamMembers?: TeamMemberV3[];
}
interface Facet {
    /** Facet type. */
    facetType?: FacetTypeWithLiterals;
    /** Values and their counters. Values with count = 0 are not returned. */
    values?: FacetValue[];
}
interface FacetValue {
    /** Supported values: `Roles`, `InviteStatus`, `Users`. */
    value?: string;
    /** Number of existing items for the value. */
    count?: number;
}
interface TeamMemberV3 extends TeamMemberV3MembersOneOf {
    /** Existing team member data. */
    user?: UserV3;
    /** Invited team member data. */
    invite?: InviteV3;
}
/** @oneof */
interface TeamMemberV3MembersOneOf {
    /** Existing team member data. */
    user?: UserV3;
    /** Invited team member data. */
    invite?: InviteV3;
}
interface UserV3 {
    /** User ID. */
    id?: string;
    /**
     * User's email address.
     * @format EMAIL
     */
    email?: string | null;
    /** User's name, when provided. */
    name?: Name;
    /** URL to user's profile image, when provided. */
    profileImage?: string | null;
    /** Date the user joined the team. */
    joinedTeamAt?: Date | null;
    /** Mapping of the user's access to an asset and their assigned role. */
    assignments?: AssignmentV3[];
}
interface AssignmentV3 {
    /** Role assigned to the user. To retrieve all available roles, call Get Roles Info. */
    policyId?: string | null;
    /**
     * Unique ID for this specific assignment.
     * @readonly
     */
    assignmentId?: string | null;
    /** The asset where a user is assigned access in an assignment. When empty, the role covers all assets, with no restrictions to specific sites or folders. */
    restrictions?: Restriction;
    /** Identity assigned to the asset in an assignment, referred to as subject. Supported subjects include user IDs, account IDs, and app IDs. */
    subject?: AssignedSubject;
}
interface AssignedSubject {
    /**
     * Identity ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /** Identity type. */
    subjectType?: SubjectTypeWithLiterals;
}
interface InviteV3 {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Invitee's email address.
     * @format EMAIL
     */
    email?: string | null;
    /** Invite status. */
    status?: InviteStatusWithLiterals;
    /** URL of direct link to accept the invite. */
    acceptLink?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /** Date the invite was last updated. */
    dateUpdated?: Date | null;
    /** A list of assignments that will be applied to the invitees when they accept the invite. */
    assignments?: InviteAssignmentV3[];
    /** Invite expiration date. */
    expirationDate?: Date | null;
}
interface InviteAssignmentV3 {
    /** Role ID that will be assigned once the invite is accepted. */
    policyId?: string | null;
    /** Assets where the user will be assigned access. When empty, the role covers all assets, with no restrictions to specific sites or folders. */
    restrictions?: Restriction;
}
declare enum RoleLevelRestriction {
    NoRestriction = "NoRestriction",
    Site = "Site",
    Account = "Account"
}
/** @enumType */
type RoleLevelRestrictionWithLiterals = RoleLevelRestriction | 'NoRestriction' | 'Site' | 'Account';
declare enum EditorType {
    UNINITIALIZED = "UNINITIALIZED",
    EDITORX = "EDITORX",
    BLOCKS = "BLOCKS",
    STUDIO = "STUDIO"
}
/** @enumType */
type EditorTypeWithLiterals = EditorType | 'UNINITIALIZED' | 'EDITORX' | 'BLOCKS' | 'STUDIO';
interface GetRolesInfoRequest {
    /** Language of predefined roles names and descriptions to return, in ISO 639 format. Default: `en`. */
    locale?: string | null;
    /** Roles to return. */
    filter?: RolesInfoFilter;
}
interface RolesInfoFilter {
    /** Role level to return. Default: ALL. */
    roleLevel?: RoleLevelWithLiterals;
    /** Filter for editor-specific roles. Default: ALL. */
    editorTypes?: EditorTypeWithLiterals[];
}
interface GetRolesInfoResponse {
    /** Predefined roles. */
    predefinedRoles?: RoleInfo[];
    /** Custom roles. */
    customRoles?: RoleInfo[];
}
interface RoleInfo {
    /** Role ID. */
    id?: string;
    /** Role title, translated according to the request locale. If translation fails, the original title is returned. */
    title?: string;
    /** Role description, translated according to the request locale. If translation fails, the original description is returned. */
    description?: string;
    /** Whether this role is restricted from accessing a specific resource type. Default: `NoRestriction`. */
    restrictFromLevel?: RoleLevelRestrictionWithLiterals;
}
interface ChangeRoleV2Request {
    /**
     * ID of team member being affected.
     * @format GUID
     */
    userId: string;
    /** New assignments, including roles, to apply to the team member in this account. To retrieve all available roles, call Get Roles Info. */
    roles: AssignmentV3[];
    /** Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team. */
    assignmentIdsToReplace: string[];
}
interface ChangeRoleV2Response {
    /** New roles assigned to the given team member. */
    roles?: AssignmentV3[];
}
interface UpdateTeamMemberAssignmentsRequest {
    /**
     * ID of team member being affected.
     * @format GUID
     */
    userId: string;
    /**
     * New assignments to apply to the team member in this account.
     * @maxSize 50
     */
    newAssignments: AssignmentV3[];
    /**
     * Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team.
     * @format GUID
     * @maxSize 50
     */
    assignmentIdsToRemove: string[];
}
interface UpdateTeamMemberAssignmentsResponse {
    /** The new assignments, assigned to the given team member. */
    assignments?: AssignmentV3[];
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function removeMember(): __PublicMethodMetaInfo<'POST', {}, RemoveMemberRequest$1, RemoveMemberRequest, RemoveMemberResponse$1, RemoveMemberResponse>;
declare function searchTeam(): __PublicMethodMetaInfo<'POST', {}, SearchTeamRequest$1, SearchTeamRequest, SearchTeamResponse$1, SearchTeamResponse>;
declare function getRolesInfo(): __PublicMethodMetaInfo<'GET', {}, GetRolesInfoRequest$1, GetRolesInfoRequest, GetRolesInfoResponse$1, GetRolesInfoResponse>;
declare function changeRoleV2(): __PublicMethodMetaInfo<'PATCH', {}, ChangeRoleV2Request$1, ChangeRoleV2Request, ChangeRoleV2Response$1, ChangeRoleV2Response>;
declare function updateTeamMemberAssignments(): __PublicMethodMetaInfo<'PATCH', {}, UpdateTeamMemberAssignmentsRequest$1, UpdateTeamMemberAssignmentsRequest, UpdateTeamMemberAssignmentsResponse$1, UpdateTeamMemberAssignmentsResponse>;

export { type __PublicMethodMetaInfo, changeRoleV2, getRolesInfo, removeMember, searchTeam, updateTeamMemberAssignments };
