// src/identity-roles-v1-user-users.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressRolesManagementApiRolesManagementServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      },
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/app/accept",
        destPath: "/app/accept"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/roles-management-web",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/v2/contributors",
        destPath: "/v2/contributors"
      },
      {
        srcPath: "/contributor/change/role",
        destPath: "/contributor/change/role"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/roles-management",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management/roles",
        destPath: "/roles"
      },
      {
        srcPath: "/roles-management/team",
        destPath: "/team"
      },
      {
        srcPath: "/roles-management/v3/team",
        destPath: "/v3/team"
      },
      {
        srcPath: "/roles-management/v2/team",
        destPath: "/v2/team"
      },
      {
        srcPath: "/roles-management/contributor/change",
        destPath: "/contributor/change"
      },
      {
        srcPath: "/roles-management/v2/contributors",
        destPath: "/v2/contributors"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_users";
function removeMember(payload) {
  function __removeMember({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "POST",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.RemoveMember",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/team/remove",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __removeMember;
}
function searchTeam(payload) {
  function __searchTeam({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "POST",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.SearchTeam",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v3/team/search",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "teamMembers.user.joinedTeamAt" },
            { path: "teamMembers.invite.dateCreated" },
            { path: "teamMembers.invite.dateUpdated" },
            { path: "teamMembers.invite.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __searchTeam;
}
function getRolesInfo(payload) {
  function __getRolesInfo({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.GetRolesInfo",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/roles",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getRolesInfo;
}
function changeRoleV2(payload) {
  function __changeRoleV2({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "PATCH",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.ChangeRoleV2",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v2/team/roles",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeRoleV2;
}
function updateTeamMemberAssignments(payload) {
  function __updateTeamMemberAssignments({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.roles.v1.user",
      method: "PATCH",
      methodFqn: "com.wixpress.roles.management.api.RolesManagementService.UpdateTeamMemberAssignments",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiRolesManagementServiceUrl({
        protoPath: "/v2/team/assignments",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __updateTeamMemberAssignments;
}

// src/identity-roles-v1-user-users.meta.ts
function removeMember2() {
  const payload = {};
  const getRequestOptions = removeMember(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/team/remove",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function searchTeam2() {
  const payload = {};
  const getRequestOptions = searchTeam(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v3/team/search",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getRolesInfo2() {
  const payload = {};
  const getRequestOptions = getRolesInfo(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/roles",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function changeRoleV22() {
  const payload = {};
  const getRequestOptions = changeRoleV2(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v2/team/roles",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateTeamMemberAssignments2() {
  const payload = {};
  const getRequestOptions = updateTeamMemberAssignments(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v2/team/assignments",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  changeRoleV22 as changeRoleV2,
  getRolesInfo2 as getRolesInfo,
  removeMember2 as removeMember,
  searchTeam2 as searchTeam,
  updateTeamMemberAssignments2 as updateTeamMemberAssignments
};
//# sourceMappingURL=meta.mjs.map